@@ -44,16 +44,3 @@ class DatasetQueryParams(BaseModel):
     field_name: Optional[str]
     value: Optional[str]
     type: str
-
-
-class DatasetAvailableParams(BaseModel):
-    company_id: Optional[str]
-    user_name: Optional[str]
-    password: Optional[str]
-
-
-class DatasetDisableParams(BaseModel):
-    company_id: Optional[str]
-    user_name: Optional[str]
-    password: Optional[str]
-    dataset_name: Optional[str]
