@@ -2,8 +2,8 @@ from typing import List, Optional
 
 from pip_fluigio.__fluig_services_base.dataset import DatasetProvider
 from pip_fluigio.__fluig_services_base.interfaces.dataset import (
-    DatasetAvailableParams, DatasetDisableParams, DatasetQuery,
-    DatasetQueryParams, StructConstraint, StructField, StructOrder)
+    DatasetQuery, DatasetQueryParams, StructConstraint, StructField,
+    StructOrder)
 from pip_fluigio.fluig_services.infraestruture.server import ClientFluig
 from pip_fluigio.utils.commomns import convert_zeep_object
 from pip_fluigio.utils.logger import Logger
@@ -43,11 +43,11 @@ class Dataset(DatasetProvider):
         dataset_name: str,
         constraints: list[DatasetQueryParams],
         fields: Optional[list] = None,
-        order: Optional[list] = None
+        order: Optional[list] = None,
     ) -> Optional[List[dict]]:
 
         try:
-            self._logger.attribute_info.info("Start request dataset")
+            self._logger.attribute.info("Start request dataset")
 
             list_fields = []
             list_order = []
@@ -106,58 +106,89 @@ class Dataset(DatasetProvider):
 
                     serialize_result.append(items)
 
-                self._logger.attribute_info.info("Finish request dataset success")
+                self._logger.attribute.info("Finish request dataset success")
                 return serialize_result
 
             else:
-                self._logger.attribute_warning.warning("Response Dataset is empty")
+                self._logger.attribute.warning("Response Dataset is empty")
                 return []
 
         except Exception as error:
-            self._logger.attribute_error.error(error)
+            self._logger.attribute.error(error)
 
-    def get_all_available_dataset(self, dataset: DatasetAvailableParams) -> List[dict]:
+    def get_all_available_dataset(
+        self, *, company_id: str, user_name: str, password: str
+    ) -> Optional[List[dict]]:
 
-        query = self._client.soap_intance.service.findAllFormulariesDatasets(
-            dataset.company_id,
-            dataset.user_name,
-            dataset.password,
-        )
+        try:
+            self._logger.attribute.info("Request all Datasets Available")
 
-        response = convert_zeep_object(query)
-        serialize_result = []
+            query = self._client.soap_intance.service.findAllFormulariesDatasets(
+                company_id,
+                user_name,
+                password,
+            )
 
-        for value in response:  # type:ignore
+            response = convert_zeep_object(query)
+            serialize_result = []
 
-            serialize_result.append(value)
+            if response:
 
-        return serialize_result
+                for value in response:  # type:ignore
 
-    def get_available_datasets(self, dataset: DatasetAvailableParams) -> List[dict]:
+                    serialize_result.append(value)
 
-        query = self._client.soap_intance.service.getAvailableDatasets(
-            dataset.company_id,
-            dataset.user_name,
-            dataset.password,
-        )
+                return serialize_result
 
-        response = convert_zeep_object(query)
+            else:
+                return []
 
-        serialize_result = []
+        except Exception as error:
+            self._logger.attribute.error(error)
 
-        for value in response:  # type:ignore
-            items = {}  # type:ignore
-            items.update({"dataset_name": value})
+    def get_available_datasets(
+        self, *, company_id: str, user_name: str, password: str
+    ) -> Optional[List[dict]]:
 
-            serialize_result.append(items)
+        try:
 
-        return serialize_result
+            self._logger.attribute.info("Request dataset built in available")
 
-    def disable_dataset(self, dataset: DatasetDisableParams) -> None:
+            query = self._client.soap_intance.service.getAvailableDatasets(
+                company_id,
+                user_name,
+                password,
+            )
+
+            response = convert_zeep_object(query)
+
+            if response:
+
+                serialize_result = []
+
+                for value in response:  # type:ignore
+                    items = {}  # type:ignore
+                    items.update({"dataset_name": value})
+
+                    serialize_result.append(items)
+
+                return serialize_result
+
+            else:
+                return []
+
+        except Exception as error:
+            self._logger.attribute.error(error)
+
+    def disable_dataset(
+        self, *, company_id: str, user_name: str, password: str, dataset_name: str
+    ) -> None:
+
+        self._logger.attribute.info(f"Disable dataset {dataset_name}")
 
         return self._client.soap_intance.service.deleteDataset(
-            dataset.company_id,
-            dataset.user_name,
-            dataset.password,
-            dataset.dataset_name,
+            company_id,
+            user_name,
+            password,
+            dataset_name,
         )
